%global libqat_soversion  3
%global libusdm_soversion 0

Summary:          Intel QuickAssist user space library
Name:             qatlib
Version:          23.02.0
Release:          5%{?dist}
License:          BSD and (BSD or GPLv2)
URL:              https://github.com/intel/%{name}
Source0:          %{url}/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:    systemd gcc make autoconf automake libtool systemd-devel openssl-devel zlib-devel nasm
Requires(pre):    shadow-utils
Recommends:       qatlib-service
ExcludeArch:      aarch64 %{power64} loongarch64

%description
Intel QuickAssist Technology (Intel QAT) provides hardware acceleration for offloading security,
authentication and compression services from the CPU, thus significantly increasing the performance
and efficiency of standard platform solutions.

Its services include symmetric encryption and authentication, asymmetric encryption, digital
signatures, RSA, DH and ECC, and lossless data compression.

This package provides user space libraries that allow access to Intel QuickAssist devices and expose
the Intel QuickAssist APIs.

%package       devel
Summary:       Headers and libraries to build applications that use qatlib
Requires:      %{name} = %{version}-%{release}

%description   devel
This package contains headers and libraries required to build applications that use the Intel
QuickAssist APIs.

%package       tests
Summary:       Sample applications that use qatlib
Requires:      %{name} = %{version}-%{release}

%description   tests
This package contains sample applications that use the Intel QuickAssists APIs.

%package       service
Summary:       A daemon for qatlib resources management
Requires:      %{name} = %{version}-%{release}
%{?systemd_requires}

%description   service
This package contains a daemon that manages QAT resources for the Intel QuickAssist Technology user
space library (qatlib).

%prep
%autosetup -n %{name}-%{version} -p1

%build
autoreconf -vif
%configure
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
sed -i -e 's! -shared ! -Wl,--as-needed\0!g' libtool
%make_build

%install
%make_install
make DESTDIR=%{buildroot} samples-install
rm %{buildroot}/%{_libdir}/libqat.la
rm %{buildroot}/%{_libdir}/libusdm.la
rm %{buildroot}/%{_libdir}/libqat.a
rm %{buildroot}/%{_libdir}/libusdm.a

%pre
getent group qat >/dev/null || groupadd -r qat
exit 0

%post          service
%systemd_post qat.service

%preun         service
%systemd_preun qat.service

%postun        service
%systemd_postun_with_restart qat.service

%files
%license LICENSE*
%doc INSTALL README.md
%{_libdir}/libqat.so.%{libqat_soversion}*
%{_libdir}/libusdm.so.%{libusdm_soversion}*

%files         devel
%{_libdir}/libqat.so
%{_libdir}/libusdm.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/qat

%files         tests
%doc quickassist/lookaside/access_layer/src/sample_code/README.txt
%attr(0754,-,qat) %{_bindir}/cpa_sample_code
%attr(0754,-,qat) %{_bindir}/dc_dp_sample
%attr(0754,-,qat) %{_bindir}/dc_stateless_sample
%attr(0754,-,qat) %{_bindir}/dc_stateless_multi_op_sample
%attr(0754,-,qat) %{_bindir}/algchaining_sample
%attr(0754,-,qat) %{_bindir}/ccm_sample
%attr(0754,-,qat) %{_bindir}/cipher_sample
%attr(0754,-,qat) %{_bindir}/gcm_sample
%attr(0754,-,qat) %{_bindir}/hash_file_sample
%attr(0754,-,qat) %{_bindir}/hash_sample
%attr(0754,-,qat) %{_bindir}/ipsec_sample
%attr(0754,-,qat) %{_bindir}/ssl_sample
%attr(0754,-,qat) %{_bindir}/sym_dp_sample
%attr(0754,-,qat) %{_bindir}/dh_sample
%attr(0754,-,qat) %{_bindir}/eddsa_sample
%attr(0754,-,qat) %{_bindir}/prime_sample
%attr(0754,-,qat) %{_bindir}/hkdf_sample
%attr(0754,-,qat) %{_bindir}/ec_montedwds_sample
%{_datadir}/qat/calgary
%{_datadir}/qat/calgary32
%{_datadir}/qat/canterbury

%files         service
%{_sbindir}/qatmgr
%{_sbindir}/qat_init.sh
%{_unitdir}/qat.service
%{_mandir}/man8/qatmgr.8*
%{_mandir}/man8/qat_init.sh.8*

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 23.02.0-5
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Thu Aug 22 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 23.02.0-4
- [Type] other
- [DESC] ExcludeArch loongarch64

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 23.02.0-3
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 23.02.0-2
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Jul 11 2023 Shuo Wang <abushwang@tencent.com> - 23.02.0-1
- update to 23.02.0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 22.07.2-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 22.07.2-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 8 2023 Shuo Wang <abushwang@tencent.com> - 22.07.2-1
- initial build
